==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/tr_tr/client_tickets.php <==
<?php
/**
 * Client Tickets
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['ClientTickets.!error.email.blacklist'] = 'Üzgünüz, şu anda biletinizi kabul edemiyoruz.';
$lang['ClientTickets.formatDepartmentCustomFields.encrypted_field'] = 'Bu veriler şifrelenmiştir ve görüntülenemez.';
$lang['ClientTickets.reply.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['ClientTickets.reply.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['ClientTickets.reply.staff_title'] = 'Destek Personeli';
$lang['ClientTickets.reply.system'] = 'Sistem';
$lang['ClientTickets.reply.log_date'] = '1$s %2$s %3$s tarafından';
$lang['ClientTickets.reply.reply_date'] = '1$s %2$s %3$s tarihinde yanıtlandı';
$lang['ClientTickets.reply.text_add_attachment'] = 'Eklenti Ekle';
$lang['ClientTickets.reply.confirm_close'] = 'Bu bileti kapatmak istediğinizden emin misiniz?';
$lang['ClientTickets.reply.field_closesubmit'] = 'Kapat';
$lang['ClientTickets.reply.field_replysubmit'] = 'Yanıtla';
$lang['ClientTickets.reply.field_attachments'] = 'Ekler';
$lang['ClientTickets.reply.field_details'] = 'Detaylar';
$lang['ClientTickets.reply.placeholder_reply'] = 'Detayları Girin';
$lang['ClientTickets.reply.heading_reply'] = 'Yanıt Ekle';
$lang['ClientTickets.reply.heading_date_added'] = 'Açıldığı Tarih';
$lang['ClientTickets.reply.heading_status'] = 'Durum';
$lang['ClientTickets.reply.heading_priority'] = 'Öncelik';
$lang['ClientTickets.reply.heading_department'] = 'Departman';
$lang['ClientTickets.reply.heading_summary'] = 'Özet';
$lang['ClientTickets.reply.boxtitle_reply'] = 'Bilet #%1$s';
$lang['ClientTickets.add.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['ClientTickets.add.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['ClientTickets.add.placeholder_details'] = 'Detayları Girin';
$lang['ClientTickets.add.placeholder_summary'] = 'Özet Girin';
$lang['ClientTickets.add.field_addsubmit'] = 'Açık Bilet';
$lang['ClientTickets.add.field_attachments'] = 'Ekler';
$lang['ClientTickets.add.field_details'] = 'Detaylar';
$lang['ClientTickets.add.field_priority'] = 'Öncelik';
$lang['ClientTickets.add.field_summary'] = 'Özet';
$lang['ClientTickets.add.field_email'] = 'E-posta';
$lang['ClientTickets.add.boxtitle_add'] = 'Açık Bilet';
$lang['ClientTickets.departments.boxtitle_departments'] = 'Destek Departmanları';
$lang['ClientTickets.index.confirm_close'] = 'Bu bileti kapatmak istediğinizden emin misiniz?';
$lang['ClientTickets.index.no_results'] = 'Şu anda bu statüde bilet bulunmamaktadır.';
$lang['ClientTickets.add.text_add_attachment'] = 'Eklenti Ekle';
$lang['ClientTickets.index.field_last_reply'] = 'Son Yanıt';
$lang['ClientTickets.index.field_summary'] = 'Özet';
$lang['ClientTickets.index.field_priority'] = 'Öncelik';
$lang['ClientTickets.index.field_ticket_number'] = 'Bilet Numarası';
$lang['ClientTickets.index.hours'] = '1$s saat';
$lang['ClientTickets.index.hour'] = '1 saat';
$lang['ClientTickets.index.minutes'] = '1$s dakika';
$lang['ClientTickets.index.any'] = 'Herhangi bir';
$lang['ClientTickets.index.option_reply'] = 'Yanıtla';
$lang['ClientTickets.index.option_close'] = 'Kapat';
$lang['ClientTickets.index.heading_options'] = 'Seçenekler';
$lang['ClientTickets.index.heading_status'] = 'Durum';
$lang['ClientTickets.index.heading_last_reply_date'] = 'Son Yanıt';
$lang['ClientTickets.index.heading_summary'] = 'Özet';
$lang['ClientTickets.index.heading_department_name'] = 'Departman';
$lang['ClientTickets.index.heading_priority'] = 'Öncelik';
$lang['ClientTickets.index.heading_code'] = 'Bilet Numarası';
$lang['ClientTickets.index.boxtitle_tickets'] = 'Biletler';
$lang['ClientTickets.index.categorylink_createticket'] = 'Açık Bilet';
$lang['ClientTickets.index.category_closed'] = 'Kapalı';
$lang['ClientTickets.index.category_open'] = 'Açık';
$lang['ClientTickets.reply.page_title'] = 'Destek > Bilet Güncelle';
$lang['ClientTickets.add.page_title'] = 'Destek > Bilet Aç';
$lang['ClientTickets.index.page_title'] = 'Destek > Biletler';
$lang['ClientTickets.!error.captcha.invalid'] = 'Girilen captcha geçersiz. Lütfen tekrar deneyin.';
$lang['ClientTickets.!notice.no_departments'] = 'Herhangi bir destek departmanı bulunmamaktadır.';
$lang['ClientTickets.!success.ticket_closed'] = '1$s numaralı bilet başarıyla kapatıldı.';
$lang['ClientTickets.!success.ticket_updated'] = '1$s numaralı bilet başarıyla güncellendi.';
$lang['ClientTickets.!success.ticket_created'] = 'Bilet #%1$s başarıyla oluşturuldu.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/tr_tr/client_tickets.php <==
<?php
/**
 * Client Tickets
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['ClientTickets.!error.email.blacklist'] = 'Üzgünüz, şu anda biletinizi kabul edemiyoruz.';
$lang['ClientTickets.formatDepartmentCustomFields.encrypted_field'] = 'Bu veriler şifrelenmiştir ve görüntülenemez.';
$lang['ClientTickets.reply.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['ClientTickets.reply.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['ClientTickets.reply.staff_title'] = 'Destek Personeli';
$lang['ClientTickets.reply.system'] = 'Sistem';
$lang['ClientTickets.reply.text_add_attachment'] = 'Eklenti Ekle';
$lang['ClientTickets.reply.confirm_close'] = 'Bu bileti kapatmak istediğinizden emin misiniz?';
$lang['ClientTickets.reply.field_closesubmit'] = 'Kapat';
$lang['ClientTickets.reply.field_replysubmit'] = 'Yanıtla';
$lang['ClientTickets.reply.field_attachments'] = 'Ekler';
$lang['ClientTickets.reply.field_details'] = 'Detaylar';
$lang['ClientTickets.reply.placeholder_reply'] = 'Detayları Girin';
$lang['ClientTickets.reply.heading_reply'] = 'Yanıt Ekle';
$lang['ClientTickets.reply.heading_date_added'] = 'Açıldığı Tarih';
$lang['ClientTickets.reply.heading_status'] = 'Durum';
$lang['ClientTickets.reply.heading_priority'] = 'Öncelik';
$lang['ClientTickets.reply.heading_department'] = 'Departman';
$lang['ClientTickets.reply.heading_summary'] = 'Özet';
$lang['ClientTickets.reply.boxtitle_reply'] = 'Bilet #%1$s';
$lang['ClientTickets.add.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['ClientTickets.add.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['ClientTickets.add.placeholder_details'] = 'Detayları Girin';
$lang['ClientTickets.add.placeholder_summary'] = 'Özet Girin';
$lang['ClientTickets.add.field_addsubmit'] = 'Açık Bilet';
$lang['ClientTickets.add.field_attachments'] = 'Ekler';
$lang['ClientTickets.add.field_details'] = 'Detaylar';
$lang['ClientTickets.add.field_priority'] = 'Öncelik';
$lang['ClientTickets.add.field_summary'] = 'Özet';
$lang['ClientTickets.add.field_email'] = 'E-posta';
$lang['ClientTickets.add.boxtitle_add'] = 'Açık Bilet';
$lang['ClientTickets.departments.boxtitle_departments'] = 'Destek Departmanları';
$lang['ClientTickets.index.confirm_close'] = 'Bu bileti kapatmak istediğinizden emin misiniz?';
$lang['ClientTickets.index.no_results'] = 'Şu anda bu statüde bilet bulunmamaktadır.';
$lang['ClientTickets.add.text_add_attachment'] = 'Eklenti Ekle';
$lang['ClientTickets.index.field_last_reply'] = 'Son Yanıt';
$lang['ClientTickets.index.field_summary'] = 'Özet';
$lang['ClientTickets.index.field_priority'] = 'Öncelik';
$lang['ClientTickets.index.field_ticket_number'] = 'Bilet Numarası';
$lang['ClientTickets.index.hour'] = '1 saat';
$lang['ClientTickets.index.any'] = 'Herhangi bir';
$lang['ClientTickets.index.option_reply'] = 'Yanıtla';
$lang['ClientTickets.index.option_close'] = 'Kapat';
$lang['ClientTickets.index.heading_options'] = 'Seçenekler';
$lang['ClientTickets.index.heading_status'] = 'Durum';
$lang['ClientTickets.index.heading_last_reply_date'] = 'Son Yanıt';
$lang['ClientTickets.index.heading_summary'] = 'Özet';
$lang['ClientTickets.index.heading_department_name'] = 'Departman';
$lang['ClientTickets.index.heading_priority'] = 'Öncelik';
$lang['ClientTickets.index.heading_code'] = 'Bilet Numarası';
$lang['ClientTickets.index.boxtitle_tickets'] = 'Biletler';
$lang['ClientTickets.index.categorylink_createticket'] = 'Açık Bilet';
$lang['ClientTickets.index.category_closed'] = 'Kapalı';
$lang['ClientTickets.index.category_open'] = 'Açık';
$lang['ClientTickets.reply.page_title'] = 'Destek > Bilet Güncelle';
$lang['ClientTickets.add.page_title'] = 'Destek > Bilet Aç';
$lang['ClientTickets.index.page_title'] = 'Destek > Biletler';
$lang['ClientTickets.!error.captcha.invalid'] = 'Girilen captcha geçersiz. Lütfen tekrar deneyin.';
$lang['ClientTickets.!notice.no_departments'] = 'Herhangi bir destek departmanı bulunmamaktadır.';
$lang['ClientTickets.!success.ticket_created'] = 'Bilet #%1$s başarıyla oluşturuldu.';
$lang['ClientTickets.reply.log_date'] = '%1$s tarafından %2$s %3$s';
$lang['ClientTickets.index.hours'] = '%1$s saat';
$lang['ClientTickets.index.minutes'] = '%1$s dakika';
$lang['ClientTickets.!success.ticket_closed'] = 'Bilet #%1$s başarıyla kapatıldı.';
$lang['ClientTickets.!success.ticket_updated'] = 'Bilet #%1$s başarıyla güncellendi.';
$lang['ClientTickets.reply.reply_date'] = '%1$s adresinde %2$s %3$s yanıtladı';
